Skip to main contentCrate feldera_rest_api
Source - builder
- Types for composing operation parameters.
- prelude
- Items consumers will typically use such as the Client.
- types
- Types used as operation parameters and responses.
- ByteStream
- Untyped byte stream used for both success and error responses.
- Client
- Client for Feldera API
- ResponseValue
- Typed value returned by generated client methods.
- RetryPolicy
- Retry behavior for transient request failures.
- Error
- Error produced by generated client methods.
- ClientInfo
- Interface for which an implementation is generated for all clients.