pub enum CheckpointActivity {
Idle,
Delayed {
delayed_since: DateTime<Utc>,
reasons: Vec<TemporarySuspendError>,
},
InProgress {
started_at: DateTime<Utc>,
},
}Expand description
Current checkpoint activity state.
JSON schema
{
"description": "Current checkpoint activity state.",
"oneOf": [
{
"type": "object",
"required": [
"status"
],
"properties": {
"status": {
"type": "string",
"enum": [
"idle"
]
}
}
},
{
"description": "A checkpoint has been requested but is delayed for temporary reasons\n(e.g. replaying, bootstrapping, transaction in progress, or input\nendpoint barriers that require the coordinator to run steps).",
"type": "object",
"required": [
"delayed_since",
"reasons",
"status"
],
"properties": {
"delayed_since": {
"description": "When the delay started (serialized as ISO 8601).",
"type": "string",
"format": "date-time"
},
"reasons": {
"description": "Why the checkpoint cannot proceed yet.",
"type": "array",
"items": {
"$ref": "#/components/schemas/TemporarySuspendError"
}
},
"status": {
"type": "string",
"enum": [
"delayed"
]
}
}
},
{
"description": "A checkpoint is currently being written to storage.",
"type": "object",
"required": [
"started_at",
"status"
],
"properties": {
"started_at": {
"description": "When the checkpoint write started (serialized as ISO 8601).",
"type": "string",
"format": "date-time"
},
"status": {
"type": "string",
"enum": [
"in_progress"
]
}
}
}
]
}Variants
Idle
Delayed
A checkpoint has been requested but is delayed for temporary reasons (e.g. replaying, bootstrapping, transaction in progress, or input endpoint barriers that require the coordinator to run steps).
Fields

reasons: Vec<TemporarySuspendError>Why the checkpoint cannot proceed yet.
InProgress
A checkpoint is currently being written to storage.