pub enum IcebergTransactionMode {
None,
Snapshot,
Catchup,
Always,
}Expand description
Iceberg table transaction mode.
Determines how the connector breaks up its input into Feldera transactions.
none- the connector does not group its input into transactions.snapshot- ingest the initial snapshot in one or more transactions (see below). Changes ingested afterward, in the follow phase, are not grouped into transactions.catchup- ingest the initial snapshot likesnapshot. In the follow phase, the connector batches all currently available table commits into a single transaction. Once that transaction completes, it checks for commits added since the transaction began, ingests them in the next transaction, and repeats continuously. Most efficient for backfill and steady-state following.always- ingest the initial snapshot likesnapshot. In the follow phase, each table commit is ingested in its own transaction.
How the table snapshot is ingested using transactions
For the initial snapshot (snapshot, catchup, and always all behave the same), the
connector ingests the snapshot in one or several transactions, depending on timestamp_column.
If timestamp_column is not set, the whole snapshot is ingested in a single Feldera
transaction. If timestamp_column is set, the connector ingests the snapshot in a series of
timestamp ranges of width equal to the LATENESS attribute of the column, each range in a
separate transaction.
JSON schema
{
"description": "Iceberg table transaction mode.\n\nDetermines how the connector breaks up its input into Feldera transactions.\n\n* `none` - the connector does not group its input into transactions.\n* `snapshot` - ingest the initial snapshot in one or more transactions (see below). Changes\ningested afterward, in the follow phase, are not grouped into transactions.\n* `catchup` - ingest the initial snapshot like `snapshot`. In the follow phase, the connector\nbatches all currently available table commits into a single transaction. Once that transaction\ncompletes, it checks for commits added since the transaction began, ingests them in the next\ntransaction, and repeats continuously. Most efficient for backfill and steady-state following.\n* `always` - ingest the initial snapshot like `snapshot`. In the follow phase, each table commit\nis ingested in its own transaction.\n\n# How the table snapshot is ingested using transactions\n\nFor the initial snapshot (`snapshot`, `catchup`, and `always` all behave the same), the\nconnector ingests the snapshot in one or several transactions, depending on `timestamp_column`.\nIf `timestamp_column` is not set, the whole snapshot is ingested in a single Feldera\ntransaction. If `timestamp_column` is set, the connector ingests the snapshot in a series of\ntimestamp ranges of width equal to the `LATENESS` attribute of the column, each range in a\nseparate transaction.",
"type": "string",
"enum": [
"none",
"snapshot",
"catchup",
"always"
]
}Variants