pub enum MemberRole {
Read,
Write,
Admin,
}Expand description
A role assignable to a tenant member: read, write, or admin. owner
is a platform-wide role, not a tenant membership, so it is not a valid value
here.
JSON schema
{
"description": "A role assignable to a tenant member: `read`, `write`, or `admin`. `owner`\nis a platform-wide role, not a tenant membership, so it is not a valid value\nhere.",
"type": "string",
"enum": [
"read",
"write",
"admin"
]
}Variants