pub enum MemoryPressure {
Low,
Moderate,
High,
Critical,
}Expand description
Memory pressure level.
The current memory pressure level is computed as a function of the current process
resident set size (RSS) and the user-configured memory limit (max_rss).
As the memory pressure level increases, the system will apply increasing backpressure to push state cached in memory to storage.
Low: less than 85% of the user-configured memory limit has been allocated.Moderate: between 85% and 90% of the user-configured memory limit has been allocated.High: between 90% and 95% of the user-configured memory limit has been allocated.Critical: more than 95% of the user-configured memory limit has been allocated.
JSON schema
{
"description": "Memory pressure level.\n\nThe current memory pressure level is computed as a function of the current process\nresident set size (RSS) and the user-configured memory limit (`max_rss`).\n\nAs the memory pressure level increases, the system will apply increasing backpressure to\npush state cached in memory to storage.\n\n- `Low`: less than 85% of the user-configured memory limit has been allocated.\n- `Moderate`: between 85% and 90% of the user-configured memory limit has been allocated.\n- `High`: between 90% and 95% of the user-configured memory limit has been allocated.\n- `Critical`: more than 95% of the user-configured memory limit has been allocated.",
"type": "string",
"enum": [
"low",
"moderate",
"high",
"critical"
]
}Variants