pub struct CommitProgressSummary {
pub completed: i64,
pub in_progress: i64,
pub in_progress_processed_records: i64,
pub in_progress_total_records: i64,
pub remaining: i64,
}Expand description
Summary of transaction commit progress.
JSON schema
{
"description": "Summary of transaction commit progress.",
"type": "object",
"required": [
"completed",
"in_progress",
"in_progress_processed_records",
"in_progress_total_records",
"remaining"
],
"properties": {
"completed": {
"description": "Number of operators that have been fully flushed.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"in_progress": {
"description": "Number of operators that are currently being flushed.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"in_progress_processed_records": {
"description": "Number of records processed by operators that are currently being flushed.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"in_progress_total_records": {
"description": "Total number of records that operators that are currently being flushed need to process.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"remaining": {
"description": "Number of operators that haven't started flushing.",
"type": "integer",
"format": "int64",
"minimum": 0.0
}
}
}Fields
completed: i64Number of operators that have been fully flushed.
in_progress: i64Number of operators that are currently being flushed.
in_progress_processed_records: i64Number of records processed by operators that are currently being flushed.
in_progress_total_records: i64Total number of records that operators that are currently being flushed need to process.
remaining: i64Number of operators that haven’t started flushing.
Implementations
Sourceimpl CommitProgressSummary
impl CommitProgressSummary
pub fn builder() -> CommitProgressSummary