pub struct Configuration {Show 13 fields
pub build_info: BuildInformation,
pub build_source: String,
pub changelog_url: String,
pub conceptualhq: String,
pub edition: String,
pub license_validity: Option<LicenseValidity>,
pub posthog: String,
pub product_fruits: String,
pub revision: String,
pub runtime_revision: String,
pub unstable_features: Option<String>,
pub update_info: Option<UpdateInformation>,
pub version: String,
}Expand description
Configuration
JSON schema
{
"type": "object",
"required": [
"build_info",
"build_source",
"changelog_url",
"conceptualhq",
"edition",
"posthog",
"product_fruits",
"revision",
"runtime_revision",
"version"
],
"properties": {
"build_info": {
"$ref": "#/components/schemas/BuildInformation"
},
"build_source": {
"description": "Build source: \"ci\" for GitHub Actions builds, \"source\" for local builds",
"type": "string"
},
"changelog_url": {
"description": "URL that navigates to the changelog of the current version",
"type": "string"
},
"conceptualhq": {
"description": "ConceptualHQ analytics key. Empty when disabled.",
"type": "string"
},
"edition": {
"description": "Feldera edition: \"Open source\" or \"Enterprise\"",
"type": "string"
},
"license_validity": {
"oneOf": [
{
"type": "null"
},
{
"allOf": [
{
"$ref": "#/components/schemas/LicenseValidity"
}
]
}
]
},
"posthog": {
"description": "PostHog telemetry key. Empty when disabled.",
"type": "string"
},
"product_fruits": {
"description": "Product Fruits workspace code for in-app onboarding. Empty when disabled.",
"type": "string"
},
"revision": {
"description": "Specific revision corresponding to the edition `version` (e.g., git commit hash).",
"type": "string"
},
"runtime_revision": {
"description": "Specific revision corresponding to the default runtime version of the platform (e.g., git commit hash).",
"type": "string"
},
"unstable_features": {
"description": "List of unstable features that are enabled.",
"type": [
"string",
"null"
]
},
"update_info": {
"oneOf": [
{
"type": "null"
},
{
"allOf": [
{
"$ref": "#/components/schemas/UpdateInformation"
}
]
}
]
},
"version": {
"description": "The version corresponding to the type of `edition`.\nFormat is `x.y.z`.",
"type": "string"
}
}
}Fields
build_info: BuildInformationbuild_source: StringBuild source: “ci” for GitHub Actions builds, “source” for local builds
changelog_url: StringURL that navigates to the changelog of the current version
conceptualhq: StringConceptualHQ analytics key. Empty when disabled.
edition: StringFeldera edition: “Open source” or “Enterprise”
license_validity: Option<LicenseValidity>posthog: StringPostHog telemetry key. Empty when disabled.
product_fruits: StringProduct Fruits workspace code for in-app onboarding. Empty when disabled.
revision: StringSpecific revision corresponding to the edition version (e.g., git commit hash).
runtime_revision: StringSpecific revision corresponding to the default runtime version of the platform (e.g., git commit hash).
unstable_features: Option<String>List of unstable features that are enabled.
update_info: Option<UpdateInformation>version: StringThe version corresponding to the type of edition.
Format is x.y.z.
Implementations
Sourceimpl Configuration
impl Configuration
pub fn builder() -> Configuration