pub struct GlobalControllerMetrics {Show 30 fields
pub bootstrap_in_progress: bool,
pub buffered_input_bytes: i64,
pub buffered_input_records: i64,
pub commit_progress: Option<CommitProgressSummary>,
pub cpu_msecs: i64,
pub incarnation_uuid: Uuid,
pub initial_start_time: i64,
pub memory_pressure: MemoryPressure,
pub memory_pressure_epoch: i64,
pub output_stall_msecs: i64,
pub pipeline_complete: bool,
pub rss_bytes: i64,
pub runtime_elapsed_msecs: i64,
pub start_time: i64,
pub state: PipelineState,
pub storage_bytes: i64,
pub storage_mb_secs: i64,
pub total_completed_records: i64,
pub total_completed_steps: i64,
pub total_initiated_steps: i64,
pub total_input_bytes: i64,
pub total_input_records: i64,
pub total_processed_bytes: i64,
pub total_processed_records: i64,
pub transaction_id: i64,
pub transaction_initiators: TransactionInitiators,
pub transaction_msecs: Option<i64>,
pub transaction_records: Option<i64>,
pub transaction_status: TransactionStatus,
pub uptime_msecs: i64,
}Expand description
Global controller metrics.
JSON schema
{
"description": "Global controller metrics.",
"type": "object",
"required": [
"bootstrap_in_progress",
"buffered_input_bytes",
"buffered_input_records",
"cpu_msecs",
"incarnation_uuid",
"initial_start_time",
"memory_pressure",
"memory_pressure_epoch",
"output_stall_msecs",
"pipeline_complete",
"rss_bytes",
"runtime_elapsed_msecs",
"start_time",
"state",
"storage_bytes",
"storage_mb_secs",
"total_completed_records",
"total_completed_steps",
"total_initiated_steps",
"total_input_bytes",
"total_input_records",
"total_processed_bytes",
"total_processed_records",
"transaction_id",
"transaction_initiators",
"transaction_status",
"uptime_msecs"
],
"properties": {
"bootstrap_in_progress": {
"description": "The pipeline has been resumed from a checkpoint and is currently bootstrapping new and modified views.",
"type": "boolean"
},
"buffered_input_bytes": {
"description": "Total number of bytes currently buffered by all endpoints.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"buffered_input_records": {
"description": "Total number of records currently buffered by all endpoints.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"commit_progress": {
"allOf": [
{
"$ref": "#/components/schemas/CommitProgressSummary"
}
]
},
"cpu_msecs": {
"description": "CPU time used by the pipeline across all threads, in milliseconds.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"incarnation_uuid": {
"description": "Uniquely identifies the pipeline process that started at start_time.",
"type": "string",
"format": "uuid"
},
"initial_start_time": {
"description": "Time at which the pipeline process from which we resumed started, in seconds since the epoch.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"memory_pressure": {
"$ref": "#/components/schemas/MemoryPressure"
},
"memory_pressure_epoch": {
"description": "Memory pressure epoch.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"output_stall_msecs": {
"description": "If the pipeline is stalled because one or more output connectors' output\nbuffers are full, this is the number of milliseconds that the current\nstall has lasted.\n\nIf this is nonzero, then the output connectors causing the stall can be\nidentified by noticing `ExternalOutputEndpointMetrics::queued_records`\nis greater than or equal to `ConnectorConfig::max_queued_records`.\n\nIn the ordinary case, the pipeline is not stalled, and this value is 0.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"pipeline_complete": {
"description": "True if the pipeline has processed all input data to completion.",
"type": "boolean"
},
"rss_bytes": {
"description": "Resident set size of the pipeline process, in bytes.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"runtime_elapsed_msecs": {
"description": "Time elapsed while the pipeline is executing a step, multiplied by the number of threads, in milliseconds.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"start_time": {
"description": "Time at which the pipeline process started, in seconds since the epoch.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"state": {
"$ref": "#/components/schemas/PipelineState"
},
"storage_bytes": {
"description": "Current storage usage in bytes.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"storage_mb_secs": {
"description": "Storage usage integrated over time, in megabytes * seconds.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"total_completed_records": {
"description": "Total number of input records processed to completion.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"total_completed_steps": {
"description": "Number of steps whose input records have been processed to completion.\n\nA record is processed to completion if it has been processed by the DBSP engine and\nall outputs derived from it have been processed by all output connectors.\n\n# Interpretation\n\nThis is a count, not a step number. If `total_completed_steps` is 0, no\nsteps have been processed to completion. If `total_completed_steps >\n0`, then the last step whose input records have been processed to\ncompletion is `total_completed_steps - 1`. A record that was ingested\nwhen `total_initiated_steps` was `n` is fully processed when\n`total_completed_steps >= n`.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"total_initiated_steps": {
"description": "Number of steps that have been initiated.\n\n# Interpretation\n\nThis is a count, not a step number. If `total_initiated_steps` is 0, no\nsteps have been initiated. If `total_initiated_steps > 0`, then step\n`total_initiated_steps - 1` has been started and all steps previous to\nthat have been completely processed by the circuit.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"total_input_bytes": {
"description": "Total number of bytes received from all endpoints.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"total_input_records": {
"description": "Total number of records received from all endpoints.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"total_processed_bytes": {
"description": "Total bytes of input records processed by the DBSP engine.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"total_processed_records": {
"description": "Total number of input records processed by the DBSP engine.",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"transaction_id": {
"description": "ID of the current transaction or 0 if no transaction is in progress.",
"type": "integer",
"format": "int64"
},
"transaction_initiators": {
"$ref": "#/components/schemas/TransactionInitiators"
},
"transaction_msecs": {
"description": "Elapsed time in milliseconds, according to `transaction_status`:\n\n- [TransactionStatus::TransactionInProgress]: Time that this transaction\nhas been in progress.\n\n- [TransactionStatus::CommitInProgress]: Time that this transaction has\nbeen committing.",
"type": [
"integer",
"null"
],
"format": "int64",
"minimum": 0.0
},
"transaction_records": {
"description": "Number of records in this transaction, according to\n`transaction_status`:\n\n- [TransactionStatus::TransactionInProgress]: Number of records added so\nfar. More records might be added.\n\n- [TransactionStatus::CommitInProgress]: Final number of records.",
"type": [
"integer",
"null"
],
"format": "int64",
"minimum": 0.0
},
"transaction_status": {
"$ref": "#/components/schemas/TransactionStatus"
},
"uptime_msecs": {
"description": "Time since the pipeline process started, including time that the\npipeline was running or paused.\n\nThis is the elapsed time since `start_time`.",
"type": "integer",
"format": "int64",
"minimum": 0.0
}
}
}Fields
bootstrap_in_progress: boolThe pipeline has been resumed from a checkpoint and is currently bootstrapping new and modified views.
buffered_input_bytes: i64Total number of bytes currently buffered by all endpoints.
buffered_input_records: i64Total number of records currently buffered by all endpoints.
commit_progress: Option<CommitProgressSummary>cpu_msecs: i64CPU time used by the pipeline across all threads, in milliseconds.
incarnation_uuid: UuidUniquely identifies the pipeline process that started at start_time.
initial_start_time: i64Time at which the pipeline process from which we resumed started, in seconds since the epoch.
memory_pressure: MemoryPressurememory_pressure_epoch: i64Memory pressure epoch.
output_stall_msecs: i64If the pipeline is stalled because one or more output connectors’ output buffers are full, this is the number of milliseconds that the current stall has lasted.
If this is nonzero, then the output connectors causing the stall can be
identified by noticing ExternalOutputEndpointMetrics::queued_records
is greater than or equal to ConnectorConfig::max_queued_records.
In the ordinary case, the pipeline is not stalled, and this value is 0.
pipeline_complete: boolTrue if the pipeline has processed all input data to completion.
rss_bytes: i64Resident set size of the pipeline process, in bytes.
runtime_elapsed_msecs: i64Time elapsed while the pipeline is executing a step, multiplied by the number of threads, in milliseconds.
start_time: i64Time at which the pipeline process started, in seconds since the epoch.
state: PipelineStatestorage_bytes: i64Current storage usage in bytes.
storage_mb_secs: i64Storage usage integrated over time, in megabytes * seconds.
total_completed_records: i64Total number of input records processed to completion.
total_completed_steps: i64Number of steps whose input records have been processed to completion.
A record is processed to completion if it has been processed by the DBSP engine and all outputs derived from it have been processed by all output connectors.
Interpretation
This is a count, not a step number. If total_completed_steps is 0, no
steps have been processed to completion. If total_completed_steps > 0, then the last step whose input records have been processed to
completion is total_completed_steps - 1. A record that was ingested
when total_initiated_steps was n is fully processed when
total_completed_steps >= n.
total_initiated_steps: i64Number of steps that have been initiated.
Interpretation
This is a count, not a step number. If total_initiated_steps is 0, no
steps have been initiated. If total_initiated_steps > 0, then step
total_initiated_steps - 1 has been started and all steps previous to
that have been completely processed by the circuit.
total_input_bytes: i64Total number of bytes received from all endpoints.
total_input_records: i64Total number of records received from all endpoints.
total_processed_bytes: i64Total bytes of input records processed by the DBSP engine.
total_processed_records: i64Total number of input records processed by the DBSP engine.
transaction_id: i64ID of the current transaction or 0 if no transaction is in progress.
transaction_initiators: TransactionInitiatorstransaction_msecs: Option<i64>Elapsed time in milliseconds, according to transaction_status:
-
TransactionStatus::TransactionInProgress: Time that this transaction has been in progress.
-
TransactionStatus::CommitInProgress: Time that this transaction has been committing.
transaction_records: Option<i64>Number of records in this transaction, according to
transaction_status:
-
TransactionStatus::TransactionInProgress: Number of records added so far. More records might be added.
-
TransactionStatus::CommitInProgress: Final number of records.
transaction_status: TransactionStatusuptime_msecs: i64Time since the pipeline process started, including time that the pipeline was running or paused.
This is the elapsed time since start_time.
Implementations
Sourceimpl GlobalControllerMetrics
impl GlobalControllerMetrics
pub fn builder() -> GlobalControllerMetrics