HttpOutputConfig

Struct HttpOutputConfig 

pub struct HttpOutputConfig {
    pub backpressure: bool,
}
Configuration for data output via HTTP.

HTTP output adapters cannot be usefully configured as part of pipeline configuration. Instead, instantiate them through the REST API as /pipelines/{pipeline_name}/egress.

JSON schema
{
 "description": "Configuration for data output via HTTP.\n\nHTTP output adapters cannot be usefully configured as part of pipeline\nconfiguration.  Instead, instantiate them through the REST API as\n`/pipelines/{pipeline_name}/egress`.",
 "type": "object",
 "properties": {
   "backpressure": {
     "description": "Apply backpressure on the pipeline when the HTTP client cannot receive\ndata fast enough.\n\nWhen this flag is set to false (the default), the HTTP connector drops data\nchunks if the client is not keeping up with its output.  This prevents\na slow HTTP client from slowing down the entire pipeline.\n\nWhen the flag is set to true, the connector waits for the client to receive\neach chunk and blocks the pipeline if the client cannot keep up.",
     "default": false,
     "type": "boolean"
   }
 }
}

Fields

backpressure: bool

Apply backpressure on the pipeline when the HTTP client cannot receive data fast enough.

When this flag is set to false (the default), the HTTP connector drops data chunks if the client is not keeping up with its output. This prevents a slow HTTP client from slowing down the entire pipeline.

When the flag is set to true, the connector waits for the client to receive each chunk and blocks the pipeline if the client cannot keep up.

Implementations