pub struct PostgresTlsConfig {
pub ssl_ca_location: Option<String>,
pub ssl_ca_pem: Option<String>,
pub ssl_certificate_chain_location: Option<String>,
pub ssl_client_key: Option<String>,
pub ssl_client_key_location: Option<String>,
pub ssl_client_location: Option<String>,
pub ssl_client_pem: Option<String>,
pub verify_hostname: Option<bool>,
}Expand description
TLS/SSL configuration for PostgreSQL connectors.
JSON schema
{
"description": "TLS/SSL configuration for PostgreSQL connectors.",
"type": "object",
"properties": {
"ssl_ca_location": {
"description": "Path to a file containing a sequence of CA certificates in PEM format.",
"type": [
"string",
"null"
]
},
"ssl_ca_pem": {
"description": "A sequence of CA certificates in PEM format.",
"type": [
"string",
"null"
]
},
"ssl_certificate_chain_location": {
"description": "The path to the certificate chain file.\nThe file must contain a sequence of PEM-formatted certificates,\nthe first being the leaf certificate, and the remainder forming\nthe chain of certificates up to and including the trusted root certificate.",
"type": [
"string",
"null"
]
},
"ssl_client_key": {
"description": "The client certificate key in PEM format.",
"type": [
"string",
"null"
]
},
"ssl_client_key_location": {
"description": "Path to the client certificate key.",
"type": [
"string",
"null"
]
},
"ssl_client_location": {
"description": "Path to the client certificate.",
"type": [
"string",
"null"
]
},
"ssl_client_pem": {
"description": "The client certificate in PEM format.",
"type": [
"string",
"null"
]
},
"verify_hostname": {
"description": "True to enable hostname verification when using TLS. True by default.",
"type": [
"boolean",
"null"
]
}
}
}Fields
ssl_ca_location: Option<String>Path to a file containing a sequence of CA certificates in PEM format.
ssl_ca_pem: Option<String>A sequence of CA certificates in PEM format.
ssl_certificate_chain_location: Option<String>The path to the certificate chain file. The file must contain a sequence of PEM-formatted certificates, the first being the leaf certificate, and the remainder forming the chain of certificates up to and including the trusted root certificate.
ssl_client_key: Option<String>The client certificate key in PEM format.
ssl_client_key_location: Option<String>Path to the client certificate key.
ssl_client_location: Option<String>Path to the client certificate.
ssl_client_pem: Option<String>The client certificate in PEM format.
verify_hostname: Option<bool>True to enable hostname verification when using TLS. True by default.
Implementations
Sourceimpl PostgresTlsConfig
impl PostgresTlsConfig
pub fn builder() -> PostgresTlsConfig