pub struct PostprocessorConfig {
pub config: Value,
pub name: String,
}Expand description
Configuration for describing a postprocessor
JSON schema
{
"description": "Configuration for describing a postprocessor",
"type": "object",
"required": [
"config",
"name"
],
"properties": {
"config": {
"description": "Arbitrary additional configuration expected by the postprocessor\nencoded as a JSON Value."
},
"name": {
"description": "Name of the postprocessor.\nAll postprocessors with the same name will perform the same task.",
"type": "string"
}
}
}Fields
config: ValueArbitrary additional configuration expected by the postprocessor encoded as a JSON Value.
name: StringName of the postprocessor. All postprocessors with the same name will perform the same task.
Implementations
Sourceimpl PostprocessorConfig
impl PostprocessorConfig
pub fn builder() -> PostprocessorConfig