pub struct PreprocessorConfig {
pub config: Value,
pub message_oriented: bool,
pub name: String,
}Expand description
Configuration for describing a preprocessor
JSON schema
{
"description": "Configuration for describing a preprocessor",
"type": "object",
"required": [
"config",
"message_oriented",
"name"
],
"properties": {
"config": {
"description": "Arbitrary additional configuration."
},
"message_oriented": {
"description": "True if the preprocessor is message-oriented: true if each preprocessor\noutput record corresponds to a whole number of of parser records.",
"type": "boolean"
},
"name": {
"description": "Name of the preprocessor.\nAll preprocessors with the same name will perform the same task.",
"type": "string"
}
}
}Fields
config: ValueArbitrary additional configuration.
message_oriented: boolTrue if the preprocessor is message-oriented: true if each preprocessor output record corresponds to a whole number of of parser records.
name: StringName of the preprocessor. All preprocessors with the same name will perform the same task.
Implementations
Sourceimpl PreprocessorConfig
impl PreprocessorConfig
pub fn builder() -> PreprocessorConfig