pub struct ProgramIr {
pub circuit_ir: Option<Value>,
pub mir: HashMap<String, MirNode>,
pub program_schema: Value,
}Expand description
Program information included in the pipeline configuration.
JSON schema
{
"description": "Program information included in the pipeline configuration.",
"type": "object",
"required": [
"mir",
"program_schema"
],
"properties": {
"circuit_ir": {
"description": "The circuit IR (the compiler's JIT `allOperators` form) that the Gen-2\nengine lowers onto the runtime to build the circuit. `None` for\nRust-compiled pipelines, whose circuit is statically linked into the binary."
},
"mir": {
"description": "The MIR of the program.",
"type": "object",
"additionalProperties": {
"$ref": "#/components/schemas/MirNode"
}
},
"program_schema": {
"description": "Program schema."
}
}
}Fields
circuit_ir: Option<Value>The circuit IR (the compiler’s JIT allOperators form) that the Gen-2
engine lowers onto the runtime to build the circuit. None for
Rust-compiled pipelines, whose circuit is statically linked into the binary.
mir: HashMap<String, MirNode>The MIR of the program.
program_schema: ValueProgram schema.
Implementations