pub struct UserMembership {
pub name: String,
pub role: Role,
pub tenant_id: TenantId,
}Expand description
One tenant a user may act in, as surfaced to that user (e.g. in the session payload that drives the web console’s tenant switcher).
JSON schema
{
"description": "One tenant a user may act in, as surfaced to that user (e.g. in the\nsession payload that drives the web console's tenant switcher).",
"type": "object",
"required": [
"name",
"role",
"tenant_id"
],
"properties": {
"name": {
"description": "The tenant's name.",
"type": "string"
},
"role": {
"$ref": "#/components/schemas/Role"
},
"tenant_id": {
"$ref": "#/components/schemas/TenantId"
}
}
}Fields
name: StringThe tenant’s name.
role: Roletenant_id: TenantIdImplementations
Sourceimpl UserMembership
impl UserMembership
pub fn builder() -> UserMembership