Module types

Module types 

Types used as operation parameters and responses.

Modules

builder
Types for composing complex structures.
defaults
Generation of default values for serde.
error
Error types.

Structs

AdHocInputConfig
Configuration for inserting data with ad-hoc queries
AdhocQueryArgs
Arguments to the /query endpoint.
ApiKeyDescr
API key descriptor.
ApiKeyId
API key identifier.
BuildInformation
Information about the build of the platform.
CalcitePlan
The Calcite plan representation of a dataflow graph.
CheckpointFailure
Information about a failed checkpoint.
CheckpointMetadata
Holds meta-data about a checkpoint that was taken for persistent storage and recovery of a circuit’s state.
CheckpointSyncFailure
Information about a failed checkpoint sync.
CheckpointSyncStatus
Checkpoint status returned by the /checkpoint/sync_status endpoint.
ClockConfig
ClockConfig
ClusterMonitorEvent
Brief cluster monitoring event with only the identifier, timestamp and health conclusions.
ClusterMonitorEventId
Cluster monitor event identifier.
ClusterMonitorEventSelectedInfo
Cluster monitor event information which has a selected subset of optional fields. If an optional field is not selected (i.e., is None), it will not be serialized.
CommitProgressSummary
Summary of transaction commit progress.
CompletedWatermark
A watermark that has been fully processed by the pipeline.
CompletionStatusArgs
URL-encoded arguments to the /completion_status endpoint.
CompletionStatusResponse
Response to a completion token status request.
CompletionTokenResponse
Response to a completion token creation request.
Condition
Condition
Configuration
Configuration
ConnectorError
ConnectorError
ConnectorHealth
ConnectorHealth
ConnectorStats
Aggregated connector error statistics.
ConnectorTransactionPhase
Connector transaction phase with debugging label.
ControllerStatus
Complete pipeline statistics returned by the /stats endpoint.
Dataflow
The JSON representation of a dataflow graph.
Demo
Demo
DevTweaks
Optional settings for tweaking Feldera internals.
ExtendedClusterMonitorEvent
Extended cluster monitoring event with full details.
FileBackendConfig
Configuration for local file system access.
GetClusterEventParameters
Query parameters to GET a cluster monitor event.
GetPipelineEventParameters
Query parameters to GET a pipeline monitor event.
GetPipelineParameters
Query parameters to GET a pipeline or a list of pipelines.
GlobalControllerMetrics
Global controller metrics.
GlueCatalogConfig
AWS Glue catalog config.
HealthStatus
HealthStatus
HttpInputConfig
Configuration for data input via HTTP.
HttpOutputConfig
Configuration for data output via HTTP.
IcebergReaderConfig
Iceberg input connector configuration.
InputEndpointMetrics
Performance metrics for an input endpoint.
InputEndpointStatus
Input endpoint status information.
LicenseInformation
LicenseInformation
MetricsParameters
Query parameters to retrieve pipeline circuit metrics.
MirInput
MirInput
MirNode
MirNode
MultihostConfig
Configuration for a multihost Feldera pipeline.
NewApiKeyRequest
Request to create a new API key.
NewApiKeyResponse
Response to a successful API key creation.
ObjectStorageConfig
ObjectStorageConfig
Op
Op
Operand
Operand
OutputEndpointMetrics
Performance metrics for an output endpoint.
OutputEndpointStatus
Output endpoint status information.
PartialProgramInfo
Program information is the result of the SQL compilation.
PatchPipeline
Partially update the pipeline (PATCH).
PipelineDiff
Summary of changes in the pipeline between checkpointed and new versions.
PipelineId
Pipeline identifier.
PipelineInfo
Pipeline information. It both includes fields which are user-provided and system-generated.
PipelineMonitorEventId
Pipeline monitor event identifier.
PipelineMonitorEventSelectedInfo
Pipeline monitor event information which has a selected subset of optional fields. If an optional field is not selected (i.e., is None), it will not be serialized.
PipelineSelectedInfo
Pipeline information which has a selected subset of optional fields. It both includes fields which are user-provided and system-generated. If an optional field is not selected (i.e., is None), it will not be serialized.
PipelineTemplateConfig
Configuration for supplying a custom pipeline StatefulSet template via a Kubernetes ConfigMap.
PostPutPipeline
Create a new pipeline (POST), or fully update an existing pipeline (PUT). Fields which are optional and not provided will be set to their empty type value (for strings: an empty string "", for objects: an empty dictionary {}).
PostStopPipelineParameters
Query parameters to POST a pipeline stop.
PostgresCdcReaderConfig
Postgres CDC input connector configuration.
PostgresReaderConfig
Postgres input connector configuration.
PostgresTlsConfig
TLS/SSL configuration for PostgreSQL connectors.
PostgresWriterConfig
Postgres output connector configuration.
PreprocessorConfig
Configuration for describing a preprocessor
ProgramConfig
Program configuration.
ProgramDiff
Summary of changes in the program between checkpointed and new versions.
ProgramError
Log, warning and error information about the program compilation.
ProgramInfo
Program information is the output of the SQL compiler.
ProgramIr
Program information included in the pipeline configuration.
ProviderAwsCognito
ProviderAwsCognito
ProviderGenericOidc
ProviderGenericOidc
PubSubInputConfig
Google Pub/Sub input connector configuration.
RedisOutputConfig
Redis output connector configuration.
Rel
Rel
RestCatalogConfig
Iceberg REST catalog config.
RustCompilationInfo
Rust compilation information.
SampleStatistics
One sample of time-series data.
ServiceStatus
ServiceStatus
SessionInfo
SessionInfo
ShortEndpointConfig
Schema definition for endpoint config that only includes the stream field.
SqlCompilationInfo
SQL compilation information.
SqlCompilerMessage
A SQL compiler error.
SqlIdentifier
An SQL identifier.
StartTransactionResponse
Response to a /start_transaction request.
StorageOptions
Storage configuration for a pipeline.
SyncConfig
SyncConfig
TenantId
TenantId
TimeSeries
Time series to make graphs in the web console easier.
TransactionInitiators
Information about entities that initiated the current transaction.
UpdateInformation
UpdateInformation
Version
Version number.

Enums

AdHocResultFormat
URL-encoded format argument to the /query endpoint.
ApiPermission
Permission types for invoking API endpoints.
AuthProvider
AuthProvider
BootstrapPolicy
BootstrapPolicy
BufferCacheAllocationStrategy
Controls how caches are shared across a foreground/background worker pair.
BufferCacheStrategy
Selects which eviction strategy backs a cache instance.
CalciteId
CalciteId
CheckpointActivity
Current checkpoint activity state.
ClusterMonitorEventFieldSelector
ClusterMonitorEventFieldSelector
CombinedDesiredStatus
CombinedDesiredStatus
CombinedStatus
CombinedStatus
CompilationProfile
Enumeration of possible compilation profiles that can be passed to the Rust compiler as an argument via cargo build --profile <>. A compilation profile affects among other things the compilation speed (how long till the program is ready to be run) and runtime speed (the performance while running).
CompletionStatus
Completion token status returned by the /completion_status endpoint.
ConnectorHealthStatus
ConnectorHealthStatus
DeltaTableTransactionMode
Delta table transaction mode.
DisplaySchedule
DisplaySchedule
IcebergCatalogType
IcebergCatalogType
IcebergIngestMode
Iceberg table read mode.
IcebergReaderConfigRestHeaders
IcebergReaderConfigRestHeaders
JsonLines
Whether JSON values can span multiple lines.
KafkaStartFromConfig
Where to begin reading a Kafka topic.
LicenseValidity
LicenseValidity
MemoryPressure
Memory pressure level.
MergerType
Which merger to use.
MetricsFormat
Circuit metrics output format.
MonitorStatus
MonitorStatus
PermanentSuspendError
Reasons why a pipeline does not support suspend and resume operations.
PipelineFieldSelector
PipelineFieldSelector
PipelineMonitorEventFieldSelector
PipelineMonitorEventFieldSelector
PipelineState
Pipeline state.
PostgresWriteMode
PostgreSQL write mode.
ProgramStatus
Program compilation status.
ResourcesDesiredStatus
ResourcesDesiredStatus
ResourcesStatus
Pipeline resources status.
RuntimeDesiredStatus
RuntimeDesiredStatus
RuntimeStatus
Runtime status of the pipeline.
StartFromCheckpoint
StartFromCheckpoint
StartFromCheckpointVariant0
StartFromCheckpointVariant0
StorageStatus
Storage status.
SuspendError
Whether a pipeline supports checkpointing and suspend-and-resume.
TemporarySuspendError
Reasons why a pipeline cannot be suspended at this time.
TransactionPhase
Transaction phase.
TransactionStatus
Transaction status summarized as a single value.